@@ -472,10 +472,6 @@ instance Enum a => Enum (Min a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Min a) where
   hashWithSalt p (Min a) = hashWithSalt p a
-
--- | @since 0.19.2
-instance Hashable1 Min where
-  liftHashWithSalt h salt (Min a) = h salt a
 #endif
 
 instance Ord a => Semigroup (Min a) where
@@ -579,10 +575,6 @@ instance Enum a => Enum (Max a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Max a) where
   hashWithSalt p (Max a) = hashWithSalt p a
-
--- | @since 0.19.2
-instance Hashable1 Max where
-  liftHashWithSalt h salt (Max a) = h salt a
 #endif
 
 instance Ord a => Semigroup (Max a) where
@@ -770,10 +762,6 @@ instance Enum a => Enum (First a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (First a) where
   hashWithSalt p (First a) = hashWithSalt p a
-
--- | @since 0.19.2
-instance Hashable1 First where
-  liftHashWithSalt h salt (First a) = h salt a
 #endif
 
 instance Semigroup (First a) where
@@ -861,10 +849,6 @@ instance Enum a => Enum (Last a) where
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Last a) where
   hashWithSalt p (Last a) = hashWithSalt p a
-
--- | @since 0.19.2
-instance Hashable1 Last where
-  liftHashWithSalt h salt (Last a) = h salt a
 #endif
 
 instance Semigroup (Last a) where
@@ -990,10 +974,6 @@ newtype WrappedMonoid m = WrapMonoid
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (WrappedMonoid a) where
   hashWithSalt p (WrapMonoid a) = hashWithSalt p a
-
--- | @since 0.19.2
-instance Hashable1 WrappedMonoid where
-  liftHashWithSalt h salt (WrapMonoid a) = h salt a
 #endif
 
 instance Monoid m => Semigroup (WrappedMonoid m) where
@@ -1083,10 +1063,6 @@ newtype Option a = Option
 #ifdef MIN_VERSION_hashable
 instance Hashable a => Hashable (Option a) where
   hashWithSalt p (Option a) = hashWithSalt p a
-
--- | @since 0.19.2
-instance Hashable1 Option where
-  liftHashWithSalt h salt (Option a) = liftHashWithSalt h salt a
 #endif
 
 instance Functor Option where
